@@ -76,6 +76,9 @@ class Repository:
             if Types.is_primitive(value=value) and getattr(entity_from_database, attr.key) != value:
                 setattr(entity_from_database, attr.key, value)
 
+        if entity_from_database is not None:
+            setattr(entity_from_database, 'updated_at', datetime.now())
+
         return entity_from_database
 
     def load(self, entity: any):
